import type { BatchId, Data, Ky, Reference, ReferenceOrEns, UploadOptions } from '../types';
/**
 * Upload chunk to a Bee node
 *
 * The chunk data consists of 8 byte span and up to 4096 bytes of payload data.
 * The span stores the length of the payload in uint64 little endian encoding.
 * Upload expects the chuck data to be set accordingly.
 *
 * @param ky Ky instance
 * @param data    Chunk data to be uploaded
 * @param postageBatchId  Postage BatchId that will be assigned to uploaded data
 * @param options Additional options like tag, encryption, pinning
 */
export declare function upload(ky: Ky, data: Uint8Array, postageBatchId: BatchId, options?: UploadOptions): Promise<Reference>;
/**
 * Download chunk data as a byte array
 *
 * @param ky Ky instance for given Bee class instance
 * @param hash Bee content reference
 *
 */
export declare function download(ky: Ky, hash: ReferenceOrEns): Promise<Data>;
