import type { Health, NodeInfo } from '../../types/debug';
import { Ky } from '../../types';
import { BeeVersions } from '../../types/debug';
export declare const SUPPORTED_BEE_VERSION_EXACT = "1.6.0-6ceadd35";
export declare const SUPPORTED_API_VERSION = "3.0.1";
export declare const SUPPORTED_DEBUG_API_VERSION = "2.0.1";
export declare const SUPPORTED_BEE_VERSION: string;
/**
 * Get health of node
 *
 * @param ky Ky debug instance
 */
export declare function getHealth(ky: Ky): Promise<Health>;
/**
 * Get information about Bee node
 *
 * @param ky Ky debug instance
 */
export declare function getNodeInfo(ky: Ky): Promise<NodeInfo>;
/**
 * Connects to a node and checks if it is a supported Bee version by the bee-js
 *
 * @param ky Ky debug instance
 *
 * @returns true if the Bee node version is supported
 * @deprecated Use `isSupportedExactVersion` instead
 */
export declare function isSupportedVersion(ky: Ky): Promise<boolean>;
/**
 * Connects to a node and checks if its version matches with the one that bee-js supports.
 *
 * Be aware that this is the most strict version check and most probably
 * you will want to use more relaxed API-versions based checks like
 * `isSupportedApiVersion`, `isSupportedMainApiVersion` or `isSupportedDebugApiVersion`
 * based on your use-case.
 *
 * @param ky
 */
export declare function isSupportedExactVersion(ky: Ky): Promise<boolean>;
/**
 * Connects to a node and checks if its main's API version matches with the one that bee-js supports.
 *
 * This is useful if you are not using `BeeDebug` class (for anything else then this check)
 * and want to make sure about compatibility.
 *
 * @param ky
 */
export declare function isSupportedMainApiVersion(ky: Ky): Promise<boolean>;
/**
 * Connects to a node and checks if its Debug API version matches with the one that bee-js supports.
 *
 * This is useful if you are not using `Bee` class in your application and want to make sure
 * about compatibility.
 *
 * @param ky
 */
export declare function isSupportedDebugApiVersion(ky: Ky): Promise<boolean>;
/**
 * Connects to a node and checks if its Main and Debug API versions matches with the one that bee-js supports.
 *
 * This should be the main way how to check compatibility for your app and Bee node.
 *
 * @param ky
 */
export declare function isSupportedApiVersion(ky: Ky): Promise<boolean>;
/**
 * Returns object with all versions specified by the connected Bee node (properties prefixed with `bee*`)
 * and versions that bee-js supports (properties prefixed with `supported*`).
 *
 * @param ky
 */
export declare function getVersions(ky: Ky): Promise<BeeVersions>;
